@@ -1,7 +1,7 @@
 package Git::CPAN::Patch::Command::Import;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Import a module into a git repository
-$Git::CPAN::Patch::Command::Import::VERSION = '2.1.0';
+$Git::CPAN::Patch::Command::Import::VERSION = '2.2.0';
 use 5.10.0;
 
 use strict;
@@ -95,7 +95,14 @@ method get_releases_from_local_file($path) {
 
 method clone_git_repo($release,$url) {
     $self->git_run( 'remote', 'add', 'cpan', $url );
-    $self->git_run( 'fetch', 'cpan' );
+    {
+        # git will output the tags on STDERR
+        local *STDERR;
+        open STDERR, '>', \my $err;
+        $self->git_run( 'fetch', 'cpan' );
+        say $err;
+    }
+    $self->git_run( config => 'cpan.module-name', $release->dist_name );
 }
 
 sub looks_like_git {
@@ -240,6 +247,7 @@ END
         say "created tag '@{[ 'v'.$release->dist_version ]}' ($commit)";
     }
 
+    $self->git_run( config => 'cpan.module-name', $release->dist_name );
 }
 
 method run {
@@ -269,7 +277,7 @@ Git::CPAN::Patch::Command::Import - Import a module into a git repository
 
 =head1 VERSION
 
-version 2.1.0
+version 2.2.0
 
 =head1 SYNOPSIS
 
