@@ -1,7 +1,7 @@
 package Git::CPAN::Patch::Role::Git;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: provides access to Git repository
-$Git::CPAN::Patch::Role::Git::VERSION = '2.1.0';
+$Git::CPAN::Patch::Role::Git::VERSION = '2.2.0';
 use strict;
 use warnings;
 
@@ -45,7 +45,7 @@ method last_imported_version {
     my $last = join "\n", $self->git_run( log => '--pretty=format:%b', '-n', 1, $last_commit );
 
     $last =~ /git-cpan-module:\ (.*?) \s+ git-cpan-version: \s+ (\S+)/sx
-        or die "Couldn't parse message:\n$last\n";
+        or die "Couldn't parse message (not cloned via git cpan import?):\n$last\n";
 
     return version->parse($2);
 }
@@ -56,7 +56,7 @@ method tracked_distribution {
     my $last = join "\n", $self->git_run( log => '--pretty=format:%b', '-n', 1, $last_commit );
 
     $last =~ /git-cpan-module:\s+ (.*?) \s+ git-cpan-version: \s+ (\S+)/sx
-        or die "Couldn't parse message:\n$last\n";
+        or die "Couldn't parse message (not cloned via git cpan import?):\n$last\n";
 
     return $1;
 }
@@ -79,7 +79,7 @@ Git::CPAN::Patch::Role::Git - provides access to Git repository
 
 =head1 VERSION
 
-version 2.1.0
+version 2.2.0
 
 =head1 AUTHOR
 
